# Author: Sergio Caponi
#
# MCP4725 Digital-to-Analogue converter library for the Virtual Hood Project




class MCP4725(object):

	_power_down_mode = {0: 0b00, 
						  1: 0b01, 
						  100: 0b10, 
						  500: 0b11}

	def __init__(self, bus, addr, smbuslib):
		self.bus = bus
		self.addr = addr
		self.smbuslib = smbuslib

	def write(self, value=0, write_to_EEPROM=False, power_down=0):
		if value < 0 or value > 4095:
			raise Exception('Value out of bounds!')

		if power_down not in self._power_down_mode:
			raise Exception('Invalid resistance for power down mode. Supported: 1, 100 and 500 (kOhms)')

		power_down_mode = self._power_down_mode[power_down]

		# Configure the output bits. Device will use fast mode (i.e. transfer in 2 bytes instead of 3)
		# if write_to_EEPROM is false
		if write_to_EEPROM:		# Transfer data in 3 bytes
			config = 0b11
			data = [
				config << 5 | power_down_mode << 1,
				value >> 4,
				value << 4 & 0xFF]		# Use mask to clip the value into an 8-bit int (and remove anything beyond)
		else:					# Transfer data in 2 bytes
			config = 0b00
			data = [
				power_down_mode << 4 | value >> 8,
				value & 0xFF]			# Use mask to clip the value again


		buf = bytes(data)

		# data must be a bytes type of length of 2 or 3
		message = self.smbuslib.i2c_msg.write(self.addr, buf)

		# Write the data onto the device
		self.bus.i2c_rdwr(message)




from distutils.core import setup

# read the contents of your description file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "DESC.md").read_text()


setup(
	name = 'pi_MCP4725',         # How you named your package folder (MyLib)
	packages = ['pi_MCP4725'],   # Chose the same as "name"
	version = '0.1.1',      # Start with a small number and increase it with every change you make
	license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
	description = 'Python module to use the MCP4725 DAC with the Raspberry Pi',   # Give a short description about your library
	long_description = long_description,
	long_description_content_type='text/markdown',
	author = 'Sergio Caponi',                   # Type in your name
	author_email = 'contactme@sergiocaponi.com',      # Type in your E-Mail
	url = 'https://github.com/sergiocaponi/pi_MCP4725',   # Provide either the link to your github or to your website
	download_url = 'https://github.com/sergiocaponi/pi_MCP4725/archive/refs/tags/v0.1.tar.gz',    # I explain this later on
	keywords = ['Raspberry Pi', 'DAC', 'MCP4725'],   # Keywords that define your package best
	install_requires=[            # I get to this in a second
					'smbus2',
			],
	classifiers=[
		'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
		'Intended Audience :: Developers',      # Define that your audience are developers
		'Operating System :: POSIX :: Linux',
		'Topic :: Software Development :: Build Tools',
		'Topic :: System :: Hardware',
		'License :: OSI Approved :: MIT License',   # Again, pick a license
		'Programming Language :: Python :: 3',
	],
)